ElErrorInterceptor class

错误拦截器,通常情况下此拦截器应当放在最后

Inheritance

Constructors

ElErrorInterceptor({String? messageMapper(DioException err) = _defaultElErrorMessageMapper})

Properties

hashCode int
The hash code for this object.
no setterinherited
messageMapper String? Function(DioException err)
自定义错误文案映射(建议用于业务侧国际化/自定义提示)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
override
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
inherited
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited