ElIcons class

Element UI 字体图标集合,总计 280 个图标,图标库的尺寸约为 55 kb,打包时会剔除未使用的图标

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

addLocation → const IconData
aim → const IconData
alarmClock → const IconData
apple → const IconData
arrowDown → const IconData
arrowLeft → const IconData
arrowRight → const IconData
arrowUp → const IconData
attract → const IconData
back → const IconData
bangZhu → const IconData
bankCard → const IconData
baseball → const IconData
basketball → const IconData
bell → const IconData
bicycle → const IconData
bottom → const IconData
bottomLeft → const IconData
bottomRight → const IconData
box → const IconData
brush → const IconData
burger → const IconData
camera → const IconData
cameraSolid → const IconData
caretBottom → const IconData
caretLeft → const IconData
caretRight → const IconData
caretTop → const IconData
chatDotRound → const IconData
chatDotSquare → const IconData
chatLineRound → const IconData
chatLineSquare → const IconData
chatRound → const IconData
chatSquare → const IconData
check → const IconData
cherry → const IconData
chicken → const IconData
circleCheck → const IconData
circleClose → const IconData
circlePlus → const IconData
circlePlusOutline → const IconData
close → const IconData
closeNotification → const IconData
cloudy → const IconData
cloudyAndSunny → const IconData
coffee → const IconData
coffeeCup → const IconData
coin → const IconData
coldDrink → const IconData
collection → const IconData
collectionTag → const IconData
connection → const IconData
coordinate → const IconData
copyDocument → const IconData
cpu → const IconData
crop → const IconData
cScaleToOriginal → const IconData
dArrowLeft → const IconData
dArrowRight → const IconData
dataAnalysis → const IconData
dataBoard → const IconData
dataLine → const IconData
date → const IconData
dCaret → const IconData
delete → const IconData
deleteLocation → const IconData
deleteSolid → const IconData
dessert → const IconData
discount → const IconData
discover → const IconData
dish → const IconData
dish1 → const IconData
document → const IconData
documentAdd → const IconData
documentChecked → const IconData
documentCopy → const IconData
documentDelete → const IconData
documentRemove → const IconData
download → const IconData
edit → const IconData
editOutline → const IconData
eleme → const IconData
error → const IconData
female → const IconData
files → const IconData
film → const IconData
finished → const IconData
firstAidKit → const IconData
folder → const IconData
folderAdd → const IconData
folderChecked → const IconData
folderDelete → const IconData
folderOpened → const IconData
folderRemove → const IconData
food → const IconData
football → const IconData
forkSpoon → const IconData
fullScreen → const IconData
goblet → const IconData
gobletFull → const IconData
gobletSquare → const IconData
gobletSquareFull → const IconData
goods → const IconData
grape → const IconData
guide → const IconData
headset → const IconData
heavyRain → const IconData
help → const IconData
hotWater → const IconData
house → const IconData
iceCream → const IconData
iceCreamRound → const IconData
iceCreamSquare → const IconData
iceDrink → const IconData
iceTea → const IconData
info → const IconData
key → const IconData
knifeFork → const IconData
lightning → const IconData
lightRain → const IconData
loading → const IconData
location → const IconData
locationInformation → const IconData
locationOutline → const IconData
lock → const IconData
lollipop → const IconData
magicStick → const IconData
male → const IconData
mapLocation → const IconData
medal → const IconData
medal1 → const IconData
message → const IconData
messageSolid → const IconData
mic → const IconData
microphone → const IconData
milkTea → const IconData
minus → const IconData
mobile → const IconData
mobilePhone → const IconData
money → const IconData
monitor → const IconData
moon → const IconData
moonNight → const IconData
more → const IconData
moreOutline → const IconData
mouse → const IconData
news → const IconData
noSmoking → const IconData
notebook1 → const IconData
notebook2 → const IconData
odometer → const IconData
officeBuilding → const IconData
open → const IconData
orange → const IconData
paperclip → const IconData
partlyCloudy → const IconData
pear → const IconData
phone → const IconData
phoneOutline → const IconData
picture → const IconData
pictureOutline → const IconData
pictureOutlineRound → const IconData
pieChart → const IconData
place → const IconData
platformEleme → const IconData
plus → const IconData
position → const IconData
postcard → const IconData
potatoStrips → const IconData
present → const IconData
priceTag → const IconData
printer → const IconData
question → const IconData
rank → const IconData
reading → const IconData
receiving → const IconData
refresh → const IconData
refreshLeft → const IconData
refreshRight → const IconData
refrigerator → const IconData
remove → const IconData
removeOutline → const IconData
sCheck → const IconData
school → const IconData
scissors → const IconData
sClaim → const IconData
sComment → const IconData
sCooperation → const IconData
sCustom → const IconData
sData → const IconData
sell → const IconData
service → const IconData
setting → const IconData
setUp → const IconData
sFinance → const IconData
sFlag → const IconData
sFold → const IconData
sGoods → const IconData
sGrid → const IconData
share → const IconData
sHelp → const IconData
ship → const IconData
sHome → const IconData
shoppingBag1 → const IconData
shoppingBag2 → const IconData
shoppingCart1 → const IconData
shoppingCart2 → const IconData
shoppingCartFull → const IconData
sManagement → const IconData
sMarketing → const IconData
smoking → const IconData
soccer → const IconData
soldOut → const IconData
sOpen → const IconData
sOperation → const IconData
sOpportunity → const IconData
sOrder → const IconData
sort → const IconData
sortDown → const IconData
sortUp → const IconData
sPlatform → const IconData
sPromotion → const IconData
sRelease → const IconData
sShop → const IconData
starOff → const IconData
starOn → const IconData
sTicket → const IconData
sTools → const IconData
stopwatch → const IconData
success → const IconData
sugar → const IconData
suitcase → const IconData
suitcase1 → const IconData
sUnfold → const IconData
sunny → const IconData
sunrise → const IconData
sunrise1 → const IconData
sunset → const IconData
switchButton → const IconData
tableLamp → const IconData
tableware → const IconData
takeawayBox → const IconData
thumb → const IconData
tickets → const IconData
time → const IconData
timer → const IconData
toiletPaper → const IconData
top → const IconData
topLeft → const IconData
topRight → const IconData
trophy → const IconData
trophy1 → const IconData
truck → const IconData
turnOff → const IconData
turnOffMicrophone → const IconData
umbrella → const IconData
unlock → const IconData
upload → const IconData
upload2 → const IconData
user → const IconData
userSolid → const IconData
values → const Map<String, IconData>
返回所有图标集合
videoCamera → const IconData
videoCameraSolid → const IconData
videoPause → const IconData
videoPlay → const IconData
view → const IconData
wallet → const IconData
warning → const IconData
warningOutline → const IconData
watch → const IconData
watch1 → const IconData
waterCup → const IconData
watermelon → const IconData
windPower → const IconData
zoomIn → const IconData
zoomOut → const IconData