ElLayoutData class

Implemented types
Mixed-in types
Available extensions
Annotations

Constructors

ElLayoutData({required double header, required double sidebar, required double rightSidebar, required double footer})

Properties

底部区域栏位置
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
导航头位置
getter/setter pair
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
右边侧边栏位置
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
侧边栏位置
getter/setter pair
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setteroverride

Methods

copyWith({double? header, double? sidebar, double? rightSidebar, double? footer}) ElLayoutData

Available on ElLayoutData, provided by the ElLayoutDataExt extension

fromJson(Map<String, dynamic>? json) ElLayoutData
将 Map 转成对象
override
merge([ElLayoutData? other]) ElLayoutData

Available on ElLayoutData, provided by the ElLayoutDataExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
将对象转成 Map 键值对
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited