ElScrollBehavior class
Element 默认滚动配置
- Inheritance
-
- Object
- ScrollBehavior
- ElScrollBehavior
Constructors
- ElScrollBehavior({Widget scrollbarBuilder(BuildContext context, Widget child, ScrollableDetails details)?, Widget overscrollIndicatorBuilder(BuildContext context, Widget child, ScrollableDetails details)?, ScrollPhysics scrollPhysicsBuilder(BuildContext context)?})
-
const
Properties
-
dragDevices
→ Set<
PointerDeviceKind> -
The device kinds that the scrollable will accept drag gestures from.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- overscrollIndicatorBuilder → Widget Function(BuildContext context, Widget child, ScrollableDetails details)?
-
构建自定义默认的过度滚动动画
final
-
pointerAxisModifiers
→ Set<
LogicalKeyboardKey> -
A set of LogicalKeyboardKeys that, when any or all are pressed in
combination with a PointerDeviceKind.mouse pointer scroll event, will
flip the axes of the scroll input.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollbarBuilder → Widget Function(BuildContext context, Widget child, ScrollableDetails details)?
-
构建自定义默认的滚动条
final
- scrollPhysicsBuilder → ScrollPhysics Function(BuildContext context)?
-
构建自定义默认的滚动行为
final
Methods
-
buildOverscrollIndicator(
BuildContext context, Widget child, ScrollableDetails details) → Widget -
Applies a GlowingOverscrollIndicator to the child widget on
TargetPlatform.android and TargetPlatform.fuchsia.
override
-
buildScrollbar(
BuildContext context, Widget child, ScrollableDetails details) → Widget -
Applies a RawScrollbar to the child widget on desktop platforms.
override
-
copyWith(
{bool? scrollbars, bool? overscroll, Set< PointerDeviceKind> ? dragDevices, MultitouchDragStrategy? multitouchDragStrategy, Set<LogicalKeyboardKey> ? pointerAxisModifiers, ScrollPhysics? physics, TargetPlatform? platform, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior}) → ScrollBehavior -
Creates a copy of this ScrollBehavior, making it possible to
easily toggle
scrollbarandoverscrollIndicatoreffects.inherited -
getKeyboardDismissBehavior(
BuildContext context) → ScrollViewKeyboardDismissBehavior -
The default keyboard dismissal behavior for ScrollView widgets.
inherited
-
getMultitouchDragStrategy(
BuildContext context) → MultitouchDragStrategy -
Configure the multi-finger drag strategy on multi-touch devices.
inherited
-
getPlatform(
BuildContext context) → TargetPlatform -
The platform whose scroll physics should be implemented.
inherited
-
getScrollPhysics(
BuildContext context) → ScrollPhysics -
The scroll physics to use for the platform given by getPlatform.
override
-
merge(
ElScrollBehavior? other) → ElScrollBehavior -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldNotify(
covariant ScrollBehavior oldDelegate) → bool -
Called whenever a ScrollConfiguration is rebuilt with a new
ScrollBehavior of the same runtimeType.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
velocityTrackerBuilder(
BuildContext context) → GestureVelocityTrackerBuilder -
Specifies the type of velocity tracker to use in the descendant
Scrollables' drag gesture recognizers, for estimating the velocity of a
drag gesture.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultOverscrollIndicatorBuilder(
BuildContext context, Widget child, ScrollableDetails details) → Widget -
defaultScrollbarBuilder(
BuildContext context, Widget child, ScrollableDetails details) → Widget -
defaultScrollPhysicsBuilder(
BuildContext context) → ScrollPhysics