ElSplitPaneThemeData class
- Mixed-in types
- Available extensions
- Annotations
Constructors
- ElSplitPaneThemeData({Axis? axis})
-
const
Properties
- axis → Axis?
-
分割器方向,默认垂直
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited
Methods
-
copyWith(
{Axis? axis}) → ElSplitPaneThemeData -
Available on ElSplitPaneThemeData, provided by the ElSplitPaneThemeDataExt extension
-
merge(
[ElSplitPaneThemeData? other]) → ElSplitPaneThemeData -
Available on ElSplitPaneThemeData, provided by the ElSplitPaneThemeDataExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- darkTheme → const ElSplitPaneThemeData
- theme → const ElSplitPaneThemeData