ChangeNotifierProxyProvider3<T, T2, T3, R extends ChangeNotifier?> class
A ChangeNotifierProvider that builds and synchronizes a ChangeNotifier with external values.
To understand better this variation of ChangeNotifierProvider, we can look into the following code using the original provider:
ChangeNotifierProvider(
create: (context) {
return MyChangeNotifier(
myModel: Provider.of<MyModel>(context, listen: false),
);
},
child: ...
)
In this example, we built a MyChangeNotifier from a value coming from
another provider: MyModel.
This works as long as MyModel never changes. But if it somehow updates,
then our ChangeNotifier will never update accordingly.
To solve this issue, we could instead use this class, like so:
ChangeNotifierProxyProvider<MyModel, MyChangeNotifier>(
create: (_) => MyChangeNotifier(),
update: (_, myModel, myNotifier) => myNotifier
..update(myModel),
child: ...
);
In that situation, if MyModel were to update, then MyChangeNotifier will
be able to update accordingly.
Notice how MyChangeNotifier doesn't receive MyModel in its constructor
anymore. It is now passed through a custom setter/method instead.
A typical implementation of such MyChangeNotifier could be:
class MyChangeNotifier with ChangeNotifier {
void update(MyModel myModel) {
// Do some custom work based on myModel that may call `notifyListeners`
}
}
-
DON'T create the ChangeNotifier inside
updatedirectly.This will cause your state to be lost when one of the values used updates. It will also cause unnecessary overhead because it will dispose the previous notifier, then subscribes to the new one.
Instead reuse the previous instance, and update some properties or call some methods.
ChangeNotifierProxyProvider<MyModel, MyChangeNotifier>(
// may cause the state to be destroyed involuntarily
update: (_, myModel, myNotifier) => MyChangeNotifier(myModel: myModel),
child: ...
);
-
PREFER using ProxyProvider when possible.
If the created object is only a combination of other objects, without http calls or similar side-effects, then it is likely that an immutable object built using ProxyProvider will work.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SingleChildStatelessWidget
- InheritedProvider<
R> - ListenableProxyProvider0<
R> - ListenableProxyProvider3<
T, T2, T3, R> - ChangeNotifierProxyProvider3
- Implemented types
- Available extensions
Constructors
-
ChangeNotifierProxyProvider3({Key? key, required Create<
R> create, required ProxyProviderBuilder3<T, T2, T3, R> update, bool? lazy, TransitionBuilder? builder, Widget? child}) -
Initializes
keyfor subclasses.
Properties
- builder → TransitionBuilder?
-
Syntax sugar for obtaining a BuildContext that can read the provider
created.
finalinherited
- elHorizontalScroll → Widget
-
Available on Widget, provided by the ElWidgetExt extension
监听鼠标水平滚动(仅限桌面端生效),其后代滚动小部件必须在 widget 层指定 ScrollControllerno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildWithChild(
BuildContext context, Widget? child) → Widget -
A build method that receives an extra
childparameter.inherited -
createElement(
) → _InheritedProviderElement< R> -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
elScrollbarBehavior(
BuildContext context, ElScrollBehavior behavior) → Widget -
Available on Widget, provided by the ElWidgetExt extension
合并祖先 ElScrollBehavior 的默认配置,如果不需要尊重祖先配置, 请直接使用 ScrollConfiguration 覆盖即可 -
noScrollbarBehavior(
BuildContext context, {Key? key, bool? overscroll, Set< PointerDeviceKind> ? dragDevices, MultitouchDragStrategy? multitouchDragStrategy, Set<LogicalKeyboardKey> ? pointerAxisModifiers, ScrollPhysics? physics, TargetPlatform? platform, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, bool enabled = true}) → Widget -
Available on Widget, provided by the ElWidgetExt extension
不使用祖先提供的默认滚动条,当使用自定义滚动条时请设置此扩展,可以防止与祖先提供的默认滚动条重叠 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited