ChildObstructionExtent class

Constructors

ChildObstructionExtent({required double leading, required double trailing})

Properties

hashCode int
The hash code for this object.
no setterinherited
leading double
Amount of space from the leading edge where this sliver obstructs its child.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing double
Amount of space from the trailing edge where this sliver obstructs its child.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(ChildObstructionExtent other) ChildObstructionExtent
operator -(ChildObstructionExtent other) ChildObstructionExtent
operator ==(Object other) bool
The equality operator.
inherited