controller property

PageController controller
finalinherited

An object that can be used to control the position to which this page view is scrolled.

Implementation

final PageController controller;