height property

double? height
finalinherited

The height of the _Tab.

If null, the height will be calculated based on the content of the _Tab. When icon is not null along with child or text, the default height is 72.0 pixels. Without an icon, the height is 46.0 pixels.

Implementation

final double? height;