padding property

EdgeInsetsGeometry? padding
finalinherited

The amount of space by which to inset the tab bar.

When isScrollable is false, this will yield the same result as if _TabBar was wrapped in a Padding widget. When isScrollable is true, the scrollable itself is inset, allowing the padding to scroll with the tab bar, rather than enclosing it.

Implementation

final EdgeInsetsGeometry? padding;