ExtentPrecalculationContext class

Constructors

ExtentPrecalculationContext({required double? viewportMainAxisExtent, required double? contentTotalExtent, required int numberOfItems, required int numberOfItemsWithEstimatedExtent})

Properties

contentTotalExtent double?
The main axis extent of the content. May not be available initially.
final
hashCode int
The hash code for this object.
no setterinherited
numberOfItems int
Number of items in the sliver.
final
numberOfItemsWithEstimatedExtent int
Number of items in the sliver with estimated extent.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewportMainAxisExtent double?
The main axis extent of the viewport. May not be available initially.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited