onAttached method
void
onAttached()
Called when the policy is attached to a SuperSliverList. Single policy may be attached to multiple SuperSliverLists.
Implementation
void onAttached() {}
Called when the policy is attached to a SuperSliverList. Single policy may be attached to multiple SuperSliverLists.
void onAttached() {}