invalidateAllExtents method

void invalidateAllExtents()

Invalidates the extent of all items in the list. All extents will be treated as estimations and will be recalculated if the ExtentPrecalculationPolicy allows for eagerly precalculating extents.

Implementation

void invalidateAllExtents() {
  assert(_delegate != null, "ListController is not attached.");
  _delegate!.invalidateAllExtents();
}