invalidateExtent method

void invalidateExtent(
  1. int index
)

Invalidates the extent of the item at index. Invalidating extent will treat the extent as an estimation and will recalculate the extent if the ExtentPrecalculationPolicy allows for eagerly precalculating extents.

Implementation

void invalidateExtent(int index) {
  assert(_delegate != null, "ListController is not attached.");
  _delegate!.invalidateExtent(index);
}