isAttached property
bool
get
isAttached
Returns true if the controller is attached to a SuperSliverList.
Implementation
bool get isAttached => _delegate != null;
Returns true if the controller is attached to a SuperSliverList.
bool get isAttached => _delegate != null;