isLocked property

bool get isLocked

Returns whether the underlying list is currently locked.

Methods that modify the underlying extent list, such as invalidateExtent, invalidateAllExtents, addItem, and removeItem, will throw if called when list is locked.

The list is locked during layout and unlock after the layout is complete.

Implementation

bool get isLocked {
  assert(_delegate != null, "ListController is not attached.");
  return _delegate!.isLocked;
}