unobstructedVisibleRange property

(int, int)? get unobstructedVisibleRange

Returns range of items indices currently visible in the viewport unobstructed by sticky headers or other obstructions.

Implementation

(int, int)? get unobstructedVisibleRange {
  assert(_delegate != null, "ListController is not attached.");
  return _delegate!.unobstructedVisibleRange;
}