ProxyProvider4<T, T2, T3, T4, R> class
A provider that builds a value based on other providers.
The exposed value is built through either create or update, then passed
to InheritedProvider.
As opposed to create, update may be called more than once.
It will be called once the first time the value is obtained, then once
whenever ProxyProvider rebuilds or when one of the providers it depends on
updates.
ProxyProvider comes in different variants such as ProxyProvider2. This is syntax sugar on the top of ProxyProvider0.
As such, ProxyProvider<A, Result> is equal to:
ProxyProvider0<Result>(
update: (context, result) {
final a = Provider.of<A>(context);
return update(context, a, result);
}
);
Whereas ProxyProvider2<A, B, Result> is equal to:
ProxyProvider0<Result>(
update: (context, result) {
final a = Provider.of<A>(context);
final b = Provider.of<B>(context);
return update(context, a, b, result);
}
);
This last parameter of update is the last value returned by either
create or update.
It is null by default.
update must not be null.
See also:
- Provider, which matches the behavior of ProxyProvider but has only
a
createcallback.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SingleChildStatelessWidget
- InheritedProvider<
R> - ProxyProvider0<
R> - ProxyProvider4
- Implemented types
- Available extensions
Constructors
-
ProxyProvider4({Key? key, Create<
R> ? create, required ProxyProviderBuilder4<T, T2, T3, T4, R> update, UpdateShouldNotify<R> ? updateShouldNotify, Dispose<R> ? dispose, bool? lazy, TransitionBuilder? builder, Widget? child}) -
Initializes
keyfor subclasses.
Properties
- builder → TransitionBuilder?
-
Syntax sugar for obtaining a BuildContext that can read the provider
created.
finalinherited
- elHorizontalScroll → Widget
-
Available on Widget, provided by the ElWidgetExt extension
监听鼠标水平滚动(仅限桌面端生效),其后代滚动小部件必须在 widget 层指定 ScrollControllerno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildWithChild(
BuildContext context, Widget? child) → Widget -
A build method that receives an extra
childparameter.inherited -
createElement(
) → _InheritedProviderElement< R> -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
elScrollbarBehavior(
BuildContext context, ElScrollBehavior behavior) → Widget -
Available on Widget, provided by the ElWidgetExt extension
合并祖先 ElScrollBehavior 的默认配置,如果不需要尊重祖先配置, 请直接使用 ScrollConfiguration 覆盖即可 -
noScrollbarBehavior(
BuildContext context, {Key? key, bool? overscroll, Set< PointerDeviceKind> ? dragDevices, MultitouchDragStrategy? multitouchDragStrategy, Set<LogicalKeyboardKey> ? pointerAxisModifiers, ScrollPhysics? physics, TargetPlatform? platform, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, bool enabled = true}) → Widget -
Available on Widget, provided by the ElWidgetExt extension
不使用祖先提供的默认滚动条,当使用自定义滚动条时请设置此扩展,可以防止与祖先提供的默认滚动条重叠 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited