RenderViewportExt extension

on

Methods

getOffsetToRevealExt(RenderObject target, double alignment, {bool esimationOnly = false, Rect? rect, Axis? axis}) RevealedOffset

Available on RenderAbstractViewport, provided by the RenderViewportExt extension

Extended version of RenderAbstractViewport.getOffsetToReveal that takes child scroll obstruction into account and thus works properly with sliver that have childObstructionExtent set.