state property
StateT
get
state
The current state.
This value may change after a call to dispatch.
Implementation
StateT get state;
The current state.
This value may change after a call to dispatch.
StateT get state;