extentEstimation property

ExtentEstimationProvider? extentEstimation
final

Optional method that can be used to override default estimated extent for each item. Initially all extents are estimated and then as the items are laid out, either through scrolling or extentPrecalculationPolicy, the actual extents are calculated and the scroll offset is adjusted to account for the difference between estimated and actual extents.

Implementation

final ExtentEstimationProvider? extentEstimation;