delayPopulatingCacheArea property
Whether the items in cache area should be built delayed.
This is an optimization that kicks in during fast scrolling, when
all items are being replaced on every frame.
With delayPopulatingCacheArea set to true, the items in cache area
are only built after the scrolling slows down.
Implementation
final bool delayPopulatingCacheArea;