extentEstimation property
Optional method that can be used to override default estimated extent for each item. Initially all extents are estimated and then as the items are laid out, either through scrolling or extentPrecalculationPolicy, the actual extents are calculated and the scroll offset is adjusted to account for the difference between estimated and actual extents.
The item index argument is nullable. If all estimated items have same extent,
the implementation should return non-zero extent for the null index. This saves
calls to extent estimation provider for large lists.
If each item has different extent, return zero for the null index.
Implementation
final ExtentEstimationProvider? extentEstimation;