extentPrecalculationPolicy property
Optional policy that can be used to asynchronously precalculate the extents of the items in the list. This can be useful allow precise scrolling on small lists where the difference between estimated and actual extents may be noticeable when interacting with the scrollbar. For larger lists precalculating extent has diminishing benefits since the error for each item does not impact the overall scroll position as much.
Implementation
final ExtentPrecalculationPolicy? extentPrecalculationPolicy;