layoutKeptAliveChildren property

bool layoutKeptAliveChildren
final

Whether children with keepAlive should be laid out. Setting this to true ensures that layout for kept alive children is maintained and proper paint transform is applied.

Implementation

final bool layoutKeptAliveChildren;