listController property

ListController? listController
final

When set provides access to extents of individual children. ListController can also be used to jump to a specific item in the list.

Implementation

final ListController? listController;