ElAnimatedGrid class
动画版本 Grid 小部件
- Inheritance
- Available extensions
Constructors
-
ElAnimatedGrid({Key? key, required double width, double? height, int? crossAxisCount, double aspectRatio = 1.0, double rowSpacing = 0.0, double columnSpacing = 0.0, Color? spacingColor, required List<
Widget> children, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.ease, VoidCallback? onEnd}) -
const
Properties
- aspectRatio → double
-
final
- child → Widget?
-
finalinherited
-
children
→ List<
Widget> -
final
- columnSpacing → double
-
final
- crossAxisCount → int?
-
final
- curve → Curve
-
finalinherited
- duration → Duration
-
finalinherited
-
effects
→ List<
Object?> -
副作用数组,当数组内的任意属性发生变化时,将会重新执行动画,注意:如果是一个对象,请务必重写 ==、hashCode 比较方法
no setteroverride
- elHorizontalScroll → Widget
-
Available on Widget, provided by the ElWidgetExt extension
监听鼠标水平滚动(仅限桌面端生效),其后代滚动小部件必须在 widget 层指定 ScrollControllerno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onEnd → VoidCallback?
-
finalinherited
- rowSpacing → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacingColor → Color?
-
final
- width → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildAnimatedWidget(
BuildContext context, CurvedAnimation animation, Map< dynamic, Tween?> tweenMap) → Widget -
构建动画小部件
override
-
createElement(
) → _StatelessHookElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
elScrollbarBehavior(
BuildContext context, ElScrollBehavior behavior) → Widget -
Available on Widget, provided by the ElWidgetExt extension
合并祖先 ElScrollBehavior 的默认配置,如果不需要尊重祖先配置, 请直接使用 ScrollConfiguration 覆盖即可 -
forEachTween(
ElTweenVisitor visitor) → void -
创建、更新 Tween 对象回调,其回调需要包含三个参数:
override
-
noScrollbarBehavior(
BuildContext context, {Key? key, bool? overscroll, Set< PointerDeviceKind> ? dragDevices, MultitouchDragStrategy? multitouchDragStrategy, Set<LogicalKeyboardKey> ? pointerAxisModifiers, ScrollPhysics? physics, TargetPlatform? platform, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, bool enabled = true}) → Widget -
Available on Widget, provided by the ElWidgetExt extension
不使用祖先提供的默认滚动条,当使用自定义滚动条时请设置此扩展,可以防止与祖先提供的默认滚动条重叠 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited