ElScrollbarShowMode enum
Element UI 滚动条显示模式
Values
-
不显示滚动条
- hover → const ElScrollbarShowMode
-
当鼠标进入滚动区域立即显示滚动条,离开则立即隐藏, 由于移动端没有 hover 事件,所以此模式在移动端将自动应用 onlyScrolling
- always → const ElScrollbarShowMode
-
一直显示滚动条
- onlyScrolling → const ElScrollbarShowMode
-
只有当滚动时才显示滚动条
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ElScrollbarShowMode> - A constant List of the values in this enum, in order of their declaration.