ExtendedTabBar class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ExtendedTabBar
- Implemented types
- Available extensions
Constructors
-
ExtendedTabBar({Key? key, required List<
Widget> tabs, TabController? controller, bool isScrollable = false, EdgeInsetsGeometry? padding, Color? indicatorColor, bool automaticIndicatorColorAdjustment = true, double indicatorWeight = 2.0, EdgeInsetsGeometry indicatorPadding = EdgeInsets.zero, Decoration? indicator, TabBarIndicatorSize? indicatorSize, Color? dividerColor, Color? labelColor, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, Color? unselectedLabelColor, TextStyle? unselectedLabelStyle, DragStartBehavior dragStartBehavior = DragStartBehavior.start, MaterialStateProperty<Color?> ? overlayColor, MouseCursor? mouseCursor, bool? enableFeedback, ValueChanged<int> ? onTap, ScrollPhysics? physics, InteractiveInkFeatureFactory? splashFactory, BorderRadius? splashBorderRadius, Axis scrollDirection = Axis.horizontal, MainAxisAlignment? mainAxisAlignment, bool foregroundIndicator = false}) -
const
Properties
- automaticIndicatorColorAdjustment → bool
-
Whether this tab bar should automatically adjust the
indicatorColor.finalinherited - controller → TabController?
-
This widget's selection and animation state.
finalinherited
- dividerColor → Color?
-
The color of the divider.
finalinherited
- dragStartBehavior → DragStartBehavior
-
Determines the way that drag start behavior is handled.
finalinherited
- elHorizontalScroll → Widget
-
Available on Widget, provided by the ElWidgetExt extension
监听鼠标水平滚动(仅限桌面端生效),其后代滚动小部件必须在 widget 层指定 ScrollControllerno setter - enableFeedback → bool?
-
Whether detected gestures should provide acoustic and/or haptic feedback.
finalinherited
- foregroundIndicator → bool
-
Whether the indicator is foreground
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicator → Decoration?
-
Defines the appearance of the selected tab indicator.
finalinherited
- indicatorColor → Color?
-
The color of the line that appears below the selected tab.
finalinherited
- indicatorPadding → EdgeInsetsGeometry
-
The padding for the indicator.
finalinherited
- indicatorSize → TabBarIndicatorSize?
-
Defines how the selected tab indicator's size is computed.
finalinherited
- indicatorWeight → double
-
The thickness of the line that appears below the selected tab.
finalinherited
- isScrollable → bool
-
Whether this tab bar can be scrolled horizontally.
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelColor → Color?
-
The color of selected tab labels.
finalinherited
- labelPadding → EdgeInsetsGeometry?
-
The padding added to each of the tab labels.
finalinherited
- labelStyle → TextStyle?
-
The text style of the selected tab labels.
finalinherited
- mainAxisAlignment → MainAxisAlignment?
-
The MainAxisAlignment of Tabs
if this is not null, we will not add Exapnded for Tab when
isScrollableis falsefinal - mouseCursor → MouseCursor?
-
The cursor for a mouse pointer when it enters or is hovering over the
individual tab widgets.
finalinherited
-
onTap
→ ValueChanged<
int> ? -
An optional callback that's called when the
_TabBaris tapped.finalinherited -
overlayColor
→ MaterialStateProperty<
Color?> ? -
Defines the ink response focus, hover, and splash colors.
finalinherited
- padding → EdgeInsetsGeometry?
-
The amount of space by which to inset the tab bar.
finalinherited
- physics → ScrollPhysics?
-
How the
_TabBar's scroll view should respond to user input.finalinherited - preferredSize → Size
-
A size whose height depends on if the tabs have both icons and text.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollDirection → Axis
-
The axis along which the tab bar scrolls.
final
- splashBorderRadius → BorderRadius?
-
Defines the clipping radius of splashes that extend outside the bounds of the tab.
finalinherited
- splashFactory → InteractiveInkFeatureFactory?
-
Creates the tab bar's InkWell splash factory, which defines
the appearance of "ink" splashes that occur in response to taps.
finalinherited
- tabHasTextAndIcon → bool
-
Returns whether the
_TabBarcontains a tab with both text and icon.no setterinherited -
tabs
→ List<
Widget> -
Typically a list of two or more
_Tabwidgets.finalinherited - unselectedLabelColor → Color?
-
The color of unselected tab labels.
finalinherited
- unselectedLabelStyle → TextStyle?
-
The text style of the unselected tab labels.
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< _TabBar> - Creates the mutable state for this widget at a given location in the tree.
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
elScrollbarBehavior(
BuildContext context, ElScrollBehavior behavior) → Widget -
Available on Widget, provided by the ElWidgetExt extension
合并祖先 ElScrollBehavior 的默认配置,如果不需要尊重祖先配置, 请直接使用 ScrollConfiguration 覆盖即可 -
noScrollbarBehavior(
BuildContext context, {Key? key, bool? overscroll, Set< PointerDeviceKind> ? dragDevices, MultitouchDragStrategy? multitouchDragStrategy, Set<LogicalKeyboardKey> ? pointerAxisModifiers, ScrollPhysics? physics, TargetPlatform? platform, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, bool enabled = true}) → Widget -
Available on Widget, provided by the ElWidgetExt extension
不使用祖先提供的默认滚动条,当使用自定义滚动条时请设置此扩展,可以防止与祖先提供的默认滚动条重叠 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited