shouldPrecalculateExtents abstract method
Called during layout to determine whether more extents should be precalculated.
- If
trueis returned, the SuperSliverList will attempt to precalculate more extents for the list. - If `false is returned, the precalculation will stop.
The context provides information about the current state of the list.
If the conditions for precalculation change, the policy should call valueDidChange to notify the SuperSliverList that the policy has changed.
Implementation
bool shouldPrecalculateExtents(ExtentPrecalculationContext context);