valueDidChange method
void
valueDidChange()
Notifies the SuperSliverList that the policy has changed. If the policy returned
false from shouldPrecalculateExtents and then the condition changed and
more extents should be precalculated, the policy calls valueDidChange to
let the SliverList know that the policy has changed and the precalculation
should be attempted again.
Implementation
void valueDidChange() {
for (final delegate in _delegates) {
delegate.valueDidChange();
}
}