extentForIndex method
Returns the extent of the item at index.
If isEstimated is true, the returned extent is an estimate and may not
have been obtained by laying out the item and measuring the item.
If isEstimated is false, the returned extent is the actual extent of
the item. However if the item is not currently in the cache area the
returned extent may be outdated and will be updated when the item is
scrolled into view, laid out and measured.
Implementation
(double, bool isEstimated) extentForIndex(int index) {
assert(_delegate != null, "ListController is not attached.");
return _delegate!.extentForIndex(index);
}