removeItem method
Signals that an item has been removed from the list at index.
This shift all extents after the index by one and will remove the
extent of the removed item.
Being able to notify the list of an item being removed is useful when eagerly precalculating extents.
Implementation
void removeItem(int index) {
assert(_delegate != null, "ListController is not attached.");
_delegate!.removeItem(index);
}