OffsetToRevealContext class

Constructors

OffsetToRevealContext({required RenderAbstractViewport viewport, required RenderObject target, required double alignment, required bool estimationOnly, required Rect? rect, required Axis? axis})

Properties

alignment double
final
axis Axis?
final
estimationOnly bool
final
hashCode int
The hash code for this object.
no setterinherited
rect Rect?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target RenderObject
final
viewport RenderAbstractViewport
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerOffsetResolvedCallback(ValueSetter<RevealedOffset> callback) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

current() OffsetToRevealContext?