SliverGeometryChildObstruction extension
Properties
- childObstructionExtent → ChildObstructionExtent?
-
Available on SliverGeometry, provided by the SliverGeometryChildObstruction extension
Returns the extent from edges in which this sliver obstructs its child.no setter
Methods
-
withChildObstructionExtent(
ChildObstructionExtent? value) → SliverGeometry -
Available on SliverGeometry, provided by the SliverGeometryChildObstruction extension
Sets the extent from the edges in which this sliver obstructs its child.