childObstructionExtent property
ChildObstructionExtent?
get
childObstructionExtent
Returns the extent from edges in which this sliver obstructs its child.
This similar to maxScrollObstructionExtent, with the biggest difference being that maxScrollObstructionExtent affects slivers after this one, while this one affects child slivers.
For pinned headers this should be the extent of the header, regardless of the scroll offset, layout or paint extent.
The value is used to determine offset when revealing child and as such should not be affected by the scroll offset.
Implementation
ChildObstructionExtent? get childObstructionExtent {
if (this is _SliverGeometryWithChildObstructionExtent) {
return (this as _SliverGeometryWithChildObstructionExtent)
._childObstructionExtent;
} else {
return null;
}
}